import requests
import urllib3

from bs4 import BeautifulSoup as bs
from bs4 import Comment

from spyderml.lib.file import save_output


def treat_objects(objects: str):
    if "," in objects:
        objects = objects.split(',')
        return objects
    return objects


def spyder_request(target):
    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
    try:
        r = requests.get(target)
        return r
    except requests.exceptions.SSLError:
        print(f"{target}:\nErro de ssl")
        exit()
    except requests.exceptions.MissingSchema:
        print(f"{target}:\nInvalid url\n http://?")
        exit()
    except requests.exceptions.InvalidSchema:
        print(f"{target} ERROR")
        exit()
    except:
        print("UNKNOWN ERROR")
        exit()


def soup_tags(document, object, file=None):
    html = bs(document.content, 'html.parser')
    results = html.find_all(object)
    for result in results:
        if file is not None:
            save_output(filename=file, text=result)
        print(result)


def soup_comments(document, file=None):
    html = bs(document.content, 'html.parser')
    comments = html.find_all(string=lambda text: isinstance(text, Comment))
    for comment in comments:
        if file is not None:
            save_output(filename=file, text=comment)
        print(comment)


def soup_attrs(document, object, file=None):
    html = bs(document.content, 'html.parser')
    if type(object) == list:
        for o in object:
            for attribute in html.select(f"[{o}]"):
                if file is not None:
                    save_output(filename=file, text=attribute)
                print(attribute)
    else:
        for attribute in html.select(f"[{object}]"):
            if file is not None:
                save_output(filename=file, text=attribute)
            print(attribute)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import argparse

from spyderml.lib.asciiarts import banner
from spyderml.lib.utils import spyder_request, treat_objects, soup_tags, soup_comments, soup_attrs
from spyderml.lib.file import open_file


class SpyderHtml:
    def __init__(self, args):
        self.args = args

    def run(self):
        print(banner())
        if self.args.file and self.args.target:
            print("Você só pode usar os argumentos (file e target) um por vez")

        elif self.args.file:
            alvos = open_file(filepath=self.args.file)
            htmls = []
            for alvo in alvos:
                htmls.append(spyder_request(alvo))
                try:
                    for html in htmls:
                        if self.args.comments and self.args.tags and self.args.attribs or self.args.comments and self.args.tags or \
                                self.args.comments and self.args.attribs or self.args.attribs and self.args.tags:
                            print("Os argumentos não podem ser executados juntos, escolha um por favor.")
                            exit()
                        elif self.args.tags:
                            tags = treat_objects(objects=self.args.tags)
                            soup_tags(document=html, object=tags, file=self.args.output)
                        elif self.args.comments:
                            soup_comments(document=html, file=self.args.output)
                        else:
                            attr = treat_objects(objects=self.args.attribs)
                            soup_attrs(document=html, object=attr, file=self.args.output)



                except AttributeError:
                    pass
        else:
            texto = spyder_request(target=self.args.target)
            if self.args.comments and self.args.tags and self.args.attribs or self.args.comments and self.args.tags or \
                    self.args.comments and self.args.attribs or self.args.attribs and self.args.tags:
                print("Os argumentos não podem ser executados juntos, escolha um por favor.")
                exit()
            elif self.args.tags:
                tags = treat_objects(objects=self.args.tags)
                soup_tags(document=texto, object=tags, file=self.args.output)
            elif self.args.comments:
                soup_comments(document=texto, file=self.args.output)
            else:
                attr = treat_objects(objects=self.args.attribs)
                soup_attrs(document=texto, object=attr, file=self.args.output)


def main():
    parser = argparse.ArgumentParser(description="A tool made to facilitate the analysis of html code.")

    parser.add_argument('-t', '--target', type=str, help="Parameter that defines the target URL "
                                                         "http://example.com/index.html")
    parser.add_argument('-f', '--file', type=str, help="Parameter that defines target URLs")

    parser.add_argument('--tags', type=str, help="Flag that defines which tags the program will bring")

    parser.add_argument('--comments', help="Flag that brings the comments", default=False, action='store_true', )

    parser.add_argument('--attribs', type=str, help="Flag that defines which attributes the application will look for.")

    parser.add_argument('-o', '--output', type=str, help="Flag that defines in which file the command output will be "
                                                         "saved.")

    args = parser.parse_args()

    sp = SpyderHtml(args)
    sp.run()


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

import os
from setuptools import find_packages, setup

# User-friendly description from README.md
current_directory = os.path.dirname(os.path.abspath(__file__))
try:
    with open(os.path.join(current_directory, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except Exception:
    long_description = ''

setup(
    # Name of the package
    name='spyder-ml',
    # Packages to include into the distribution
    packages=find_packages('.'),
    # Start with a small number and increase it with
    # every change you make https://semver.org
    version='0.3.7',
    # Chose a license from here: https: //
    # help.github.com / articles / licensing - a -
    # repository. For example: MIT.
    license='MIT',
    # Short description of your library
    description='A tool made to facilitate the analysis of html code.',
    # Long description of your library
    long_description=long_description,
    long_description_content_type='text/markdown',
    # Your name
    author='Lucas dSilva',
    # Your email
    author_email='accessmaker.mlbb@gmail.com',
    # Either the link to your GitHub or to your website
    url='https://github.com/accessmaker/Spyder-ml',
    # Link from which the project can be downloaded
    download_url='https://github.com/accessmaker/Spyder-ml.git',
    # List of keywords
    keywords=["spyderml", "web", "security"],
    # List of packages to install with this one
    install_requires=["bs4", "requests", "urllib3", "setuptools", "colorama"],
    # https://pypi.org/classifiers/
    classifiers=['Development Status :: 5 - Production/Stable'],
    scripts=["spyderml/bin/spyderml"]
)
